liv: Likelihood Interval for Variance of Single Sample from Normal...

livR Documentation

Likelihood Interval for Variance of Single Sample from Normal Distribution

Description

Likelihood interval for variance of single sample assuming normal distribution. Likelihood function plot is also shown. For faster calculation speed, plot option '0' is recommended.

Arguments

data

a numeric vector of data values; mandatory

conf.level

confidence level for the interval estimation

df

degree of freedom for likelihood interval; default is 1.2

k

cutoff value for likelihood interval. If not specified, F-test is used.

Value

demo

basic demographics of data

LI

estimated interval of variance by LI

LI.sd

estimated interval of standard deviation by LI

CI

estimated interval of variance by CI

plot

likelihood-related plots

Author(s)

Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>

Examples

  set.seed(2026)
  liv(rnorm(30, 0, 1))

inteli documentation built on May 24, 2026, 5:06 p.m.