qlim: Testing Function for Mean Difference of Two Samples from...

qlimR Documentation

Testing Function for Mean Difference of Two Samples from Normal Distribution by LI Method

Description

Testing function for mean difference of two samples assuming normal distribution by LI method. O2 type likelihood function plot is also shown.

Arguments

set.a

a numeric vector of former data values; mandatory

set.b

a numeric vector of latter data values; mandatory

conf.level

confidence level for the interval estimation

df

degree of freedom for likelihood interval; default is 1

k

cutoff value for likelihood interval. If not specified, F-test is used.

Value

demo

basic demographics of data

interval

estimated interval by LI and CI. PE is mean(set.a) - mean(set.b).

stat

statistical values, such as p-value and likelihood ratio

verdict

estimation result as a sentence

plot

log likelihood function plot (O2 type)

Author(s)

Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>

Examples

  x <- rnorm(30, 0, 1)
  y <- rnorm(20, 0, 1)
  qlim(x, y)

inteli documentation built on May 24, 2026, 5:06 p.m.