| qlipois | R Documentation |
Testing function for Poisson mean of single sample assuming Poisson distribution by LI method. O2 type likelihood function plot is also shown.
data |
a numeric vector of data values; mandatory |
test.val |
a numeric vector of testing value for Poisson mean; mandatory |
conf.level |
confidence level for the interval estimation |
eps |
machine epsilon value; default is 1e-08 |
k |
cutoff value for likelihood interval. If not specified, F-test is used. |
demo |
basic demographics of data |
interval |
estimated interval by LI and CI. |
stat |
statistical values, such as p-value and likelihood ratio |
verdict |
estimation result as a sentence |
plot |
log likelihood function plot (O2 type) |
Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>
qlipois(rnorm(20, 1, 1), 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.