qliv: Testing Function for Variance Ratio of Two Samples from...

qlivR Documentation

Testing Function for Variance Ratio of Two Samples from Normal Distribution

Description

Testing function for variance ratio of two samples assuming normal distribution by LI method. O2 type likelihood function plot is also shown. Smaller sample is allocated to be in the nominator for more accurate and precise estimation.

Arguments

set.a

a numeric vector of data values; mandatory, pre-allocation

set.b

a numeric vector of data values; mandatory, pre-allocation

conf.level

confidence level for the interval estimation

df

degree of freedom for likelihood interval; default is 2.4

k

cutoff value for likelihood interval. If not specified, F-test is used.

Value

demo

basic demographics of data

interval

estimated interval by LI and CI.

stat

statistical values, such as p-value and likelihood ratio

verdict

estimation result as a sentence

plot

log likelihood function plot (O2 type)

Author(s)

Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>

Examples

  x <- rnorm(30, 0, 1)
  y <- rnorm(20, 0, 1)
  qliv(x, y) # x placed in the denominator

inteli documentation built on May 24, 2026, 5:06 p.m.