Learn R Programming

inteli (version 0.1.1)

varRplot: varRplot: Plot of Variance Ratio Estimate by Likelihood Method

Description

This function plots a graph of interval estimation for a two group variance ratio by LI method, either in the log-likelihood function or the normalized log-likelihood value.

Usage

varRplot(
  num.data,
  denom.data,
  logLRT = FALSE,
  conf.level = 0.95,
  df = 2.4,
  low.scale = 5,
  up.scale = 5,
  k
)

Value

Plotted graph, either in the log-likelihood function or the normalized log-likelihood value

Arguments

num.data

A numeric vector functioning as a sample data, in a numerator position.

denom.data

A numeric vector functioning as a sample data, in a denominator position.

logLRT

A function type to be plotted. A default value "FALSE" refers to the log-likelihood function plot, while "TRUE" refers to the normalized log-likelihood ratio plot, or maxLL - LL.

conf.level

A confidence level for the CI method, also applied to the LI method.

df

A degree of freedom for the LI method in terms of the denominator degree of freedom of the F-test, or (n-df) of the LRT, where n is the sample size of the input data. A default value of 2.4 is suggested for a two-group variance ratio interval estimation.

low.scale

A scaling factor for plotting the minimum value of the x-axis, or a parameter value. The plot starts with "PE/low.scale". 5 is a default.

up.scale

A scaling factor for plotting the maximum value of the x-axis, or a parameter value. The plot starts with "PE*up.scale". 5 is a default.

k

A cutoff value for the LI method. Unless specified, the F-test is used.

Examples

Run this code
x <- rnorm(20, 0, 1)
y <- rnorm(40, 0, 1)
varRplot(x, y, FALSE)
varRplot(x, y, TRUE)

Run the code above in your browser using DataLab