| lipois | R Documentation |
Likelihood interval for Poisson mean of single sample assuming Poisson distribution. Likelihood function plot is also shown. For faster calculation speed, plot option '0' is recommended.
event |
number of events; a numeric vector |
unit.time |
unit time for Poisson mean; default is 1 |
data.size |
sample size. If not specified, size is assumed to be 1. For LI being more precise, sample size must be considered. |
conf.level |
confidence level for the interval estimation |
eps |
machine epsilon value; default is 1e-08 |
k |
cutoff value for likelihood interval. If not specified, F-test is used. |
demo |
basic demographics of data |
LI |
estimated interval of Poisson mean by LI |
CI |
estimated interval of Poisson mean by CI |
plot |
likelihood-related plots |
Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>
lipois(8)
lipois(event = 8, unit.time = 3)
lipois(event = 8, unit.time = 3, data.size = 6)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.