| lir | R Documentation |
Likelihood interval for variance ratio of two samples assuming normal distribution. Likelihood function plot is also shown. For faster calculation speed, plot option '0' is recommended. Sample size is not allocated.
num.data |
a numeric vector of data values, variance value at the numerator position; mandatory |
denom.data |
a numeric vector of data values, variance value at the denominator position; mandatory |
conf.level |
confidence level for the interval estimation |
df.t |
temporary degree of freedom for likelihood interval, default is 2.4. Sample size ratio is considered for the final degree of freedom. |
k |
cutoff value for likelihood interval. If not specified, F-test is used. |
demo |
basic demographics of data |
LI |
estimated interval of variance ratio by LI |
LI.sdR |
estimated interval of standard deviation ratio by LI |
CI |
estimated interval of variance by CI |
plot |
likelihood-related plots |
Kyun-Seop Bae <k@acr.kr>, Minkyu Kim <mkim@acr.kr>
set.seed(2026)
lir(rnorm(30, 0, 1), rnorm(30, 0, 1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.