varEplot: varEplot: Plot of Variance Estimate by Likelihood Method
Description
This function plots a graph of interval estimation for a single group variance by LI method, either in the log-likelihood function or the normalized log-likelihood value.
Plotted graph, either in the log-likelihood function or the normalized log-likelihood value.
Arguments
data
A numeric vector functioning as a sample data.
logLRT
A function type to be plotted. A default value "FALSE" refers to the log-likelihood function plot, while "TRUE" refers to the normalized log-likelihood ratio plot, or maxLL - LL.
conf.level
A confidence level for the CI method, also applied to the LI method.
df
A degree of freedom for the LI method in terms of the denominator degree of freedom of the F-test, or (n-df) of the LRT, where n is the sample size of the input data. A default value of 1.2 is suggested for a single-group variance interval estimation.
low.scale
A scaling factor for plotting the minimum value of the x-axis, or a parameter value. The plot starts with "PE/low.scale". 3 is a default.
up.scale
A scaling factor for plotting the maximum value of the x-axis, or a parameter value. The plot starts with "PE*up.scale". 5 is a default.
k
A cutoff value for the LI method. Unless specified, the F-test is used.